%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Function that outputs a struct "settings" with the settings used in the
% GNSS-aided INS
% 
% Edit: Isaac Skog (skog@kth.se), 2016-09-01 
% Revised: Bo Bernhardsson 2018-01-01
% Revised: Claudio Mandrioli 2019-02-26
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function settings=get_settings_cycling()



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%              GENERAL PARAMETERS         %% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%settings.non_holonomic = 'off';
%settings.speed_aiding = 'off';

settings.init_heading = 320*pi/180;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%             FILTER PARAMETERS           %% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Process noise covariance (Q)
% Standard deviations, need to be squared
settings.sigma_acc = 0.50; % [m/s^2]
settings.sigma_gyro = 1.0*pi/180; % [rad/s]
settings.sigma_acc_bias = 0.0001; % [m/s^2.5]
settings.sigma_gyro_bias = 0.01*pi/180; % [rad/s^1.5]


% GNSS position measurement noise covariance (R)
% Standard deviations, need to be squared
settings.sigma_gps = 1/sqrt(3);%3/sqrt(3); %[m] 

% Initial Kalman filter uncertainties (standard deviations)  
settings.factp(1) = 10;                                 % Position [m]
settings.factp(2) = 5;                                  % Velocity [m/s]
settings.factp(3:5) = (pi/180*[1 1 20]');               % Attitude (roll,pitch,yaw) [rad]
settings.factp(6) = 0.02;                               % Accelerometer biases [m/s^2]
settings.factp(7) = (0.05*pi/180);                      % Gyro biases [rad/s]                               

      
end




