%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script for example of energy-accuracy trade-off evaluatio with the
% cycling trace
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Load data
disp('Loads data')
load('cycling_input_data');

%% Load filter settings
disp('Loads settings')
settings=get_settings_cycling();

%vector of RGB colors for plotting for the different P references
color=[[0.7,0.0,0.0];[0.0,0.7,0.0];[0.7,0.0,0.7];[0.0,0.0,0.7];[0.0,0.7,0.7];[0.7,0.7,0.0]];
%vector of refrences for P
P_treshold=[4.0,5.0,6.0,8.0,10.0,12.0];
%nubmer of simulations per each P
n_run=3;
%allocate memory for output
energy=zeros(n_run,length(P_treshold));
error=zeros(n_run,length(P_treshold));

%% Iterate over the threshold for tr(P)
for j=1:length(P_treshold)   
    disp(['Starting simulations with threshold for P equal to:', num2str(P_treshold(j))]) %display reached treshold
    settings.P_treshold=P_treshold(j);                   %set P reference
    for k=1:n_run                                        %iterate over the number of simulations per threshold
        disp(['Simulation number:',num2str(k)])                                       %display simulation number
        out_data=GPSaidedINS_cycling(in_data,settings);  % Run the GNSS-aided INS
        energy(k,j)=out_data.energy;                     % store energy
        error(k,j)=out_data.error;                       % store positioning error
    end
end


%% Plot data
figure
hold on
xlabel('energy')
ylabel('error')
title('cycling energy accuracy tracking trade-off')
grid

for j=1:length(P_treshold)
    scatter(energy(:,j), error(:,j),20,color(j,:),'o','filled')
end